'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.locationReducer = locationReducer;
exports.updateLocation = updateLocation;
exports.connectHistory = connectHistory;

var _history = require('history');

var UPDATE_LOCATION = 'UPDATE_LOCATION';

var initialState = (0, _history.createLocation)();

function locationReducer() {
  var state = arguments.length <= 0 || arguments[0] === undefined ? initialState : arguments[0];
  var action = arguments[1];

  if (action.type === UPDATE_LOCATION) {
    return Object.assign({}, state, action.payload);
  }
  return state;
}

function updateLocation(location) {
  return {
    type: UPDATE_LOCATION,
    payload: location
  };
}

function connectHistory(history, store) {

  var currentKey = undefined;

  function createUniqueKey(location) {
    return history.createPath(location);
  }

  var unsubscribeHistory = history.listen(function (nextLocation) {
    var _store$getState = store.getState();

    var location = _store$getState.location;

    var key = createUniqueKey(location);
    currentKey = createUniqueKey(nextLocation);

    if (key != currentKey) {
      store.dispatch(updateLocation(nextLocation));
    }
  });

  var unsubscribeStore = store.subscribe(function () {
    var _store$getState2 = store.getState();

    var location = _store$getState2.location;

    var key = createUniqueKey(location);

    if (key !== currentKey) {
      var method = location.action === 'REPLACE' ? 'replace' : 'push';
      history[method](location);
    }
  });

  return function unconnectHistory() {
    unsubscribeHistory();
    unsubscribeStore();
  };
}